==> ejc-hrmanage-api-3.0.0-20240705.021049-106-sources.jar: com/ejianc/business/hr/vo/AccessVO.java <==
package com.ejianc.business.hr.vo;


import com.fasterxml.jackson.annotation.JsonFormat;

import java.math.BigDecimal;
import java.util.Date;

/**
 * 人员考核明细
 *
 * @author generator
 */
public class AccessVO{
    private String zid;//主键
    private String aid;//员工编号
    private String khxs;//考核类别 月度、季度
    private String khdj;//考核等级
    private String nf;//考核名称
    private String khpj;//考核评价
    private String khmc;//考核名称
    private BigDecimal fs;//分数
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date khsj;//考核时间
    private String yearf;//年
    private String yf;//月
    private String dwid;//单位
    private String dw;//单位
    private String bmid;//部门
    private String bm;//部门
    private String name;//姓名
    private String gw;//岗位
    private String zzxh;//组织序号
    private String xl;//学历
    private String zcjb;//职称级别
    private String url;//链接

    public String getUrl() {
        return url;
    }

    public void setUrl(String url) {
        this.url = url;
    }

    public String getZid() {
        return zid;
    }

    public void setZid(String zid) {
        this.zid = zid;
    }

    public String getKhdj() {
        return khdj;
    }

    public void setKhdj(String khdj) {
        this.khdj = khdj;
    }

    public String getNf() {
        return nf;
    }

    public void setNf(String nf) {
        this.nf = nf;
    }

    public String getKhpj() {
        return khpj;
    }

    public void setKhpj(String khpj) {
        this.khpj = khpj;
    }

    public String getAid() {
        return aid;
    }

    public void setAid(String aid) {
        this.aid = aid;
    }

    public String getKhxs() {
        return khxs;
    }

    public void setKhxs(String khxs) {
        this.khxs = khxs;
    }

    public String getKhmc() {
        return khmc;
    }

    public void setKhmc(String khmc) {
        this.khmc = khmc;
    }

    public BigDecimal getFs() {
        return fs;
    }

    public void setFs(BigDecimal fs) {
        this.fs = fs;
    }

    public Date getKhsj() {
        return khsj;
    }

    public void setKhsj(Date khsj) {
        this.khsj = khsj;
    }

    public String getYearf() {
        return yearf;
    }

    public void setYearf(String yearf) {
        this.yearf = yearf;
    }

    public String getYf() {
        return yf;
    }

    public void setYf(String yf) {
        this.yf = yf;
    }

    public String getDwid() {
        return dwid;
    }

    public void setDwid(String dwid) {
        this.dwid = dwid;
    }

    public String getDw() {
        return dw;
    }

    public void setDw(String dw) {
        this.dw = dw;
    }

    public String getBmid() {
        return bmid;
    }

    public void setBmid(String bmid) {
        this.bmid = bmid;
    }

    public String getBm() {
        return bm;
    }

    public void setBm(String bm) {
        this.bm = bm;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getGw() {
        return gw;
    }

    public void setGw(String gw) {
        this.gw = gw;
    }

    public String getZzxh() {
        return zzxh;
    }

    public void setZzxh(String zzxh) {
        this.zzxh = zzxh;
    }

    public String getXl() {
        return xl;
    }

    public void setXl(String xl) {
        this.xl = xl;
    }

    public String getZcjb() {
        return zcjb;
    }

    public void setZcjb(String zcjb) {
        this.zcjb = zcjb;
    }
}

==> ejc-hrmanage-api-3.0.0-20240911.081358-148-sources.jar: com/ejianc/business/hr/vo/AccessVO.java <==
package com.ejianc.business.hr.vo;


import com.fasterxml.jackson.annotation.JsonFormat;
import org.apache.commons.codec.binary.Base64;

import java.math.BigDecimal;
import java.net.URLDecoder;
import java.net.URLEncoder;
import java.util.Date;

/**
 * 人员考核明细
 *
 * @author generator
 */
public class AccessVO{
    private String zid;//主键
    private String aid;//员工编号
    private String khxs;//考核类别 月度、季度
    private String khdj;//考核等级
    private String nf;//考核名称
    private String khpj;//考核评价
    private String khmc;//考核名称
    private BigDecimal fs;//分数
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date khsj;//考核时间
    private String yearf;//年
    private String yf;//月
    private String dwid;//单位
    private String dw;//单位
    private String bmid;//部门
    private String bm;//部门
    private String name;//姓名
    private String gw;//岗位
    private String zzxh;//组织序号
    private String xl;//学历
    private String zcjb;//职称级别
    private String url;//链接

    public String getUrl() {
        return url;
    }

    public void setUrl(String url) {
        this.url = url;
    }

    public String getZid() {
        return zid;
    }

    public void setZid(String zid) {
        this.zid = zid;
    }

    public String getKhdj() {
        return khdj;
    }

    public void setKhdj(String khdj) {
        this.khdj = khdj;
    }

    public String getNf() {
        return nf;
    }

    public void setNf(String nf) {
        this.nf = nf;
    }

    public String getKhpj() {
        return khpj;
    }

    public void setKhpj(String khpj) {
        this.khpj = khpj;
    }

    public String getAid() {
        return aid;
    }

    public void setAid(String aid) {
        this.aid = aid;
    }

    public String getKhxs() {
        return khxs;
    }

    public void setKhxs(String khxs) {
        this.khxs = khxs;
    }

    public String getKhmc() {
        return khmc;
    }

    public void setKhmc(String khmc) {
        this.khmc = khmc;
    }

    public BigDecimal getFs() {
        return fs;
    }

    public void setFs(BigDecimal fs) {
        this.fs = fs;
    }

    public Date getKhsj() {
        return khsj;
    }

    public void setKhsj(Date khsj) {
        this.khsj = khsj;
    }

    public String getYearf() {
        return yearf;
    }

    public void setYearf(String yearf) {
        this.yearf = yearf;
    }

    public String getYf() {
        return yf;
    }

    public void setYf(String yf) {
        this.yf = yf;
    }

    public String getDwid() {
        return dwid;
    }

    public void setDwid(String dwid) {
        this.dwid = dwid;
    }

    public String getDw() {
        return dw;
    }

    public void setDw(String dw) {
        this.dw = dw;
    }

    public String getBmid() {
        return bmid;
    }

    public void setBmid(String bmid) {
        this.bmid = bmid;
    }

    public String getBm() {
        return bm;
    }

    public void setBm(String bm) {
        this.bm = bm;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getGw() {
        return gw;
    }

    public void setGw(String gw) {
        this.gw = gw;
    }

    public String getZzxh() {
        return zzxh;
    }

    public void setZzxh(String zzxh) {
        this.zzxh = zzxh;
    }

    public String getXl() {
        return xl;
    }

    public void setXl(String xl) {
        this.xl = xl;
    }

    public String getZcjb() {
        return zcjb;
    }

    public void setZcjb(String zcjb) {
        this.zcjb = zcjb;
    }

    public static void main(String[] args) throws Exception {

        String userCode = "周明军1124";
        String employeeCode = "00000003";
        //登录账号+,999912310000
        userCode = userCode + ",999912310000";


        String etoken = URLEncoder.encode(EncryptBase64(userCode), "GBK");
        String content_base64 = URLEncoder.encode(EncryptBase64(employeeCode), "GBK");
        String url = "http://hr.zzyjjt.com/module/card/cardCommonSearch.do?inforkind=1`&a0100="
                + content_base64
                + "`tabid=1`callbackfunc=window.close`fieldpriv=1`cardFlag=1&appfwd=1&etoken="
                + etoken;

        System.out.println(url);
        String baseUrl = "TKrr2OSVPAATTP2HJBPAATTPExh5LyPAATTP2HJFPAATTPd4PAATTP2HJBPAATTPJywPAATTP3HJDPAATTPPAATTP3HJDPAATTP";
        String decodeUrl = URLDecoder.decode(baseUrl, "GBK");
        System.out.println(decodeUrl);

        System.out.println(DecryptBase64(decodeUrl));
    }

    public static String EncryptBase64(String a_strString) throws Exception {
        Base64 base64 = new Base64();
        String base64str = new String(base64.encode(a_strString
                .getBytes("GBK")), "GBK");
        base64str = base64str.replace("\n", "");
        return base64str;
    }

    public static String EncryptBase64(byte[] bytes) throws Exception {
        Base64 base64 = new Base64();
        String base64str = new String(base64.encode(bytes), "GBK");
        base64str = base64str.replace("\n", "");
        return base64str;
    }

    public static String DecryptBase64(String a_strString) throws Exception {
        Base64 base64 = new Base64();
        byte[] bytes = base64.decode(a_strString);
        String str = new String(bytes, "GBK");
        return str;
    }

    public static byte[] DecryptBase64ForByte(String a_strString)
            throws Exception {
        Base64 base64 = new Base64();
        byte[] bytes = base64.decode(a_strString);
        return bytes;
    }
}
